PaginationDots class
A widget that displays a row of pagination dots.
The PaginationDots widget is used to indicate the current active page in a paginated view. It displays a series of dots, with one dot highlighted to represent the active page.
The number of dots is determined by the totalItems parameter, and the currently active dot is determined by the activeIndex parameter.
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- PaginationDots
Constructors
- PaginationDots({required int totalItems, required int activeIndex, EdgeInsetsGeometry padding = const EdgeInsets.symmetric(vertical: 12), required Color selectedColor, required Color unselectedColor, Key? key})
-
Default constructor
const
Properties
- activeIndex → int
-
The currently active item index.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry
-
The padding around the pagination dots.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- selectedColor → Color
-
The color of the selected dot.
final
- totalItems → int
-
The amount of total items.
final
- unselectedColor → Color
-
The color of the unselected dots.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited